==> gcal-3.6.3.tar.gz: gcal-3.6.3/src/hd-data5.h <==
#ifndef __HD_DATA5_H
# define __HD_DATA5_H
/*
*  hd-data4.h:  All other T-Z countries data which is composed into the
*               eternal holiday list header file.
*
*
*  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
*  Copyright (c) 2010, 2011, 2013 Free Software Foundation, Inc.
*
*  This software doesn't claim completeness, correctness or usability.
*  On principle I will not be liable for ANY damages or losses (implicit
*  or explicit), which result from using or handling my software.
*  If you use this software, you agree without any exception to this
*  agreement, which binds you LEGALLY !!
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the `GNU General Public License' as published by
*  the `Free Software Foundation'; either version 3, or (at your option)
*  any later version.
*
*  You should have received a copy of the `GNU General Public License'
*  along with this program; if not, write to the:
*
*/



/*
*  $Id: hd-data5.h 3.01 2000/06/14 03:00:01 tom Exp $
*/



/*
*  GLOBAL functions prototypes.
*/
__BEGIN_DECLARATIONS
/*
************************************************** Defined in `hd-data5.c'.
*/
extern void
  tc_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  td_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tg_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  th_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tj_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tk_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tm_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tn_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  to_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tr_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tt_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tv_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tw_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tz_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ua_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ug_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  us_ak_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_al_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ar_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_az_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ca_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_co_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ct_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_dc_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_de_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_fl_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ga_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_hi_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ia_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_id_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_il_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_in_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ks_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ky_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_la_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ma_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_md_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_me_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_mi_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_mn_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_mo_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ms_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_mt_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nc_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nd_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ne_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nh_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nj_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nm_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nv_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ny_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_oh_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ok_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_or_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_pa_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ri_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_sc_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_sd_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_tn_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_tx_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ut_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_va_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_vt_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_wa_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_wi_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_wv_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_wy_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  uy_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  uz_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vc_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ve_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vg_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vi_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vn_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vu_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  wf_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ws_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ye_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  yt_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  yu_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  za_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  zm_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  zw_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
__END_DECLARATIONS
#endif /* __HD_DATA5_H */

==> gcal_4.2.0.orig.tar.gz: gcal-4.2.0/src/hd-data5.h <==
#ifndef __HD_DATA5_H
# define __HD_DATA5_H
/*!
*  \file hd-data5.h
*  \brief All other T-Z countries data which is composed into the
*               eternal holiday list header file.
*/
/*
*  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
*  Copyright (c) 2010, 2011, 2013 Free Software Foundation, Inc.
*
*  This software doesn't claim completeness, correctness or usability.
*  On principle I will not be liable for ANY damages or losses (implicit
*  or explicit), which result from using or handling my software.
*  If you use this software, you agree without any exception to this
*  agreement, which binds you LEGALLY !!
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the `GNU General Public License' as published by
*  the `Free Software Foundation'; either version 3, or (at your option)
*  any later version.
*
*  You should have received a copy of the `GNU General Public License'
*  along with this program; if not, write to the:
*
*/



/*
*  $Id: hd-data5.h 3.01 2000/06/14 03:00:01 tom Exp $
*/



/*
*  GLOBAL functions prototypes.
*/
__BEGIN_DECLARATIONS
/*
************************************************** Defined in `hd-data5.c'.
*/
extern void
  tc_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  td_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tg_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  th_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tj_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tk_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tm_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tn_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  to_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tr_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tt_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tv_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tw_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  tz_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ua_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ug_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  us_ak_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_al_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ar_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_az_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ca_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_co_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ct_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_dc_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_de_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_fl_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ga_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_hi_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ia_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_id_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_il_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_in_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ks_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ky_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_la_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ma_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_md_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_me_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_mi_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_mn_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_mo_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ms_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_mt_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nc_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nd_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ne_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nh_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nj_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nm_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_nv_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ny_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_oh_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ok_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_or_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_pa_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ri_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_sc_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_sd_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_tn_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_tx_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_ut_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_va_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_vt_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_wa_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_wi_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_wv_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  us_wy_hdy __P_ ((Bool * init_data,
		   const Bool detected,
		   int easter,
		   const int year,
		   int *hd_elems, const int fday, const int count));
extern void
  uy_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  uz_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vc_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ve_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vg_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vi_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vn_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  vu_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  wf_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ws_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  ye_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  yt_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  yu_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  za_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  zm_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
extern void
  zw_hdy __P_ ((Bool * init_data,
		const Bool detected,
		int easter,
		const int year,
		int *hd_elems, const int fday, const int count));
__END_DECLARATIONS
#endif /* __HD_DATA5_H */
